"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.qwikNxVite = void 0;
const tslib_1 = require("tslib");
const get_vendor_roots_1 = require("./utils/get-vendor-roots");
const devkit_1 = require("@nx/devkit");
/**
 * `qwikNxVite` plugin serves as an integration step between Qwik and Nx.
 * At this point its main purpose is to provide Nx libraries as vendor roots for the Qwik.
 * This is required in order for the optimizer to be able to work with entities imported from those libs.
 *
 * By default `qwikNxVite` plugin will provide Qwik with paths of Nx projects,
 * that are recognized as dependencies of the current one and are specified in the tsconfig.base.json.
 * this behavior is customizable: you can exclude additional projects by providing `options.excludeProjects.keepUnrelatedProjects`,
 * or completely control what's included by using `options.includeProjects`
 */
function qwikNxVite(options) {
    const vitePlugin = {
        name: 'vite-plugin-qwik-nx',
        enforce: 'pre',
        configResolved(config) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const qwikPlugins = config.plugins.filter((p) => p.name === 'vite-plugin-qwik');
                if (!qwikPlugins.length) {
                    throw new Error('Missing vite-plugin-qwik');
                }
                if (qwikPlugins.length > 1) {
                    devkit_1.output.warn({
                        title: 'Multiple instances of "vite-plugin-qwik" found. Check your vite.config!',
                    });
                }
                for (const qwikPlugin of qwikPlugins) {
                    // it's not expected to have the plugin duplicated, but handling it as an edge case
                    const pluginOptions = qwikPlugin.api.getOptions();
                    const vendorRoots = yield (0, get_vendor_roots_1.getVendorRoots)(options, pluginOptions);
                    pluginOptions.vendorRoots.push(...vendorRoots);
                }
            });
        },
    };
    return vitePlugin;
}
exports.qwikNxVite = qwikNxVite;
//# sourceMappingURL=qwik-nx-vite.plugin.js.map