"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addCommonQwikDependencies = void 0;
const devkit_1 = require("@nx/devkit");
const versions_1 = require("./versions");
function addCommonQwikDependencies(tree) {
    var _a;
    const { satisfies } = (0, devkit_1.ensurePackage)('semver', '*');
    // TODO: refactor to use "addDependenciesToPackageJson" with "keepExistingVersions" once we support nx 17.3 or higher
    const devDependencies = {
        '@builder.io/qwik': versions_1.qwikVersion,
        '@builder.io/qwik-city': versions_1.qwikCityVersion,
        '@types/node': versions_1.typesNodeVersion,
        'eslint-plugin-qwik': versions_1.qwikEslintPluginVersion,
        vite: versions_1.viteVersion,
        vitest: versions_1.vitestVersion,
        'vite-tsconfig-paths': versions_1.viteTsconfigPathsVersion,
        'node-fetch': versions_1.nodeFetchVersion,
        undici: versions_1.undiciVersion,
    };
    const currentPackageJson = (0, devkit_1.readJson)(tree, 'package.json');
    const unsupportedPackageVersions = new Map([
        // https://github.com/vitejs/vite/issues/15870
        ['vite', '<5.1.0'],
    ]);
    let hasChanges = false;
    for (const [dep, versionRange] of unsupportedPackageVersions.entries()) {
        const existingVersion = (_a = currentPackageJson.dependencies[dep]) !== null && _a !== void 0 ? _a : currentPackageJson.devDependencies[dep];
        if (existingVersion && !satisfies(existingVersion, versionRange)) {
            hasChanges = true;
            // remove the dependency if it is set with incompatible version
            // we'll install our version instead
            delete currentPackageJson.dependencies[dep];
            delete currentPackageJson.devDependencies[dep];
        }
    }
    if (hasChanges) {
        (0, devkit_1.writeJson)(tree, 'package.json', currentPackageJson);
    }
    return (0, devkit_1.addDependenciesToPackageJson)(tree, {}, 
    // installing only those deps that are not found
    Object.fromEntries(Object.entries(devDependencies).filter(([dep]) => {
        var _a;
        const exists = (_a = currentPackageJson.dependencies[dep]) !== null && _a !== void 0 ? _a : currentPackageJson.devDependencies[dep];
        return !exists;
    })));
}
exports.addCommonQwikDependencies = addCommonQwikDependencies;
//# sourceMappingURL=add-common-qwik-dependencies.js.map